@@ -9,6 +9,7 @@ import pytest
 from julia.core import UnsupportedPythonError
 
 from .test_compatible_exe import runcode
+from .utils import _retry_on_failure, retry_failing_if_windows
 
 try:
     from types import SimpleNamespace
@@ -35,9 +36,25 @@ def test_unsupported_python_error_dynamically_linked():
     assert "have to match exactly" in str(err)
 
 
+def test_retry_on_failure():
+    c = [0]
+
+    def f():
+        c[0] += 1
+        assert c[0] >= 2
+
+    _retry_on_failure(f)
+    assert c[0] == 2
+
+
 @pytest.mark.pyjulia__using_default_setup
 @pytest.mark.julia
 def test_atexit():
+    check_atexit()
+
+
+@retry_failing_if_windows
+def check_atexit():
     proc = runcode(
         '''
         import os
